
# Type: local_name_source


the ncname of the source of the name

URI: [meta:local_name_source](https://w3id.org/biolink/biolinkml/meta/local_name_source)


## Domain and Range

[LocalName](LocalName.md) ->  <sub>REQ</sub> [Ncname](types/Ncname.md)

## Parents


## Children


## Used by

 * [LocalName](LocalName.md)
